if select(2, UnitClass("player")) ~= "SHAMAN" then return end

local function create_fontstring(name, parent, template, text)
	local fontstring = parent:CreateFontString(name, "ARTWORK", template)
	fontstring:SetText(text)
	return fontstring
end

local function create_button(name, parent, text)
	local button = CreateFrame("button", name, parent, "GameMenuButtonTemplate")
	button:SetText(text)
	return button
end

local function create_chkbutton(name, parent, text)
	local chkbutton = CreateFrame("CheckButton", name, parent, "InterfaceOptionsCheckButtonTemplate")
	chkbutton.text = _G[chkbutton:GetName() .. "Text"]
	chkbutton.text:SetText(text)
	return chkbutton
end

local function create_dropdown(name, parent, text)
	local dropdown = CreateFrame("frame", name, parent, "UIDropDownMenuTemplate")
	dropdown:SetClampedToScreen(true)
	if text then
		dropdown.title = _G[dropdown:GetName().."Title"]
		dropdown.title = create_fontstring(dropdown.title, parent, "GameFontNormal", text)
		dropdown.title:SetPoint("BOTTOMLEFT", dropdown, "TOPLEFT", 18, 2)
	end
	return dropdown
end

local function create_colorpickerbuton(name, parent, text)
	local button = CreateFrame("button", name, parent)
	button:SetSize(16, 16)
	button:SetNormalTexture("Interface/ChatFrame/ChatFrameColorSwatch")
	button.bg = _G[button:GetName().."Bg"]
	button.bg = button:CreateTexture(nil, "BACKGROUND")
	button.bg:SetSize(14, 14)
	button.bg:SetTexture(1, 1, 1)
	button.bg:SetPoint("CENTER")
	button.title = _G[button:GetName().."title"]
	button.title = create_fontstring(button.title, parent, "GameFontNormal", text)
	button.title:SetPoint("CENTER", button, "CENTER", 0, 21)
	return button
end

local function create_slider(name, parent, hightext, lowtext, high, low, text)
	local slider = CreateFrame("Slider", name, parent, "OptionsSliderTemplate")
	slider.high = _G[slider:GetName().."High"]
	slider.high:SetText(hightext)
	slider.low = _G[slider:GetName().."Low"]
	slider.low:SetText(lowtext)
	slider.text = _G[slider:GetName().."Text"]
	slider.text:SetPoint("BOTTOMRIGHT", name, 4, 0)
	slider.text:SetFontObject("GameFontHighlightSmall")
	slider:SetWidth(200)
	slider:SetMinMaxValues(low, high)
	slider:SetValueStep(1)
	slider.title = _G[slider:GetName().."Title"]
	slider.title = create_fontstring(slider.title, parent, "GameFontNormal", text)
	slider.title:SetPoint("BOTTOMLEFT", slider, "TOPLEFT", -4, 0)
	return slider
end

local function resetall()
	TeOptions = TeResetOptions()
	MwSetColor()
	MwSetTexture()
	MwSetSize()
	LavaSurgeSetSize()
	ShockSetTexture()
	WpSetScale()
	WbSetRadius()
	TtSetRadius()
	TtSetScale()
	TeBlizzMove()
	TeLockFrame()
	options.panel.refresh()
end

local function MwSoundOnClick(self)
	UIDropDownMenu_SetSelectedID(options.procpanel.MwSoundDropDown, self:GetID())
	TeOptions.Mw.Sound = self.value
	if self.value == NONE then self.value = nil else
		PlaySoundFile("Interface\\AddOns\\TribalEnhancement\\Sound\\"..self.value..".mp3")
	end
end

local function MwSoundInitialize(self, level)
	local soundFiles = {
		NONE,
		"Sample1",
		"Sample2",
	}
	local info = UIDropDownMenu_CreateInfo()
	for k,v in pairs(soundFiles) do
		info = UIDropDownMenu_CreateInfo()
		info.text = v
		info.value = v
		info.func = MwSoundOnClick
		UIDropDownMenu_AddButton(info, level)
		if v == TeOptions.Mw.Sound then
			UIDropDownMenu_SetSelectedID(options.procpanel.MwSoundDropDown, k)
		end
	end
end

local function LavaSurgeSoundOnClick(self)
	UIDropDownMenu_SetSelectedID(options.procpanel.LavaSurgeSoundDropDown, self:GetID())
	TeOptions.Lsurge.Sound = self.value
	if self.value == NONE then self.value = nil else
		PlaySoundFile(self.value)
	end
end

local function LavaSurgeSoundInitialize(self, level)
	local soundbank = getsoundbank()
	local info = UIDropDownMenu_CreateInfo()
	for k,v in pairs(soundbank) do
		info = UIDropDownMenu_CreateInfo()
		info.text = v
		info.value = v
		info.func = LavaSurgeSoundOnClick
		UIDropDownMenu_AddButton(info, level)
		if v == TeOptions.Lsurge.Sound then
			UIDropDownMenu_SetSelectedID(options.procpanel.LavaSurgeSoundDropDown, k)
		end
	end
end

local function MwTextureOnClick(self)
	UIDropDownMenu_SetSelectedID(options.procpanel.MwTextureDropDown, self:GetID())
	TeOptions.Mw.Texture = self.value
	MwSetTexture()
end

local function MwTextureInitialize(self, level)
	local textureFiles = {
		"TribalVector1",
		"TribalVector2",
		"TribalVector3",
		"TribalVector4",
		"TribalVector5",
	}
	local info = UIDropDownMenu_CreateInfo()
	for k,v in pairs(textureFiles) do
		info = UIDropDownMenu_CreateInfo()
		info.text = v
		info.value = v
		info.func = MwTextureOnClick
		UIDropDownMenu_AddButton(info, level)
		if v == TeOptions.Mw.Texture then
			UIDropDownMenu_SetSelectedID(options.procpanel.MwTextureDropDown, k)
		end
	end
end

local function MwColorSelect_Swatch()
	local a, r, v, b = OpacitySliderFrame:GetValue(), ColorPickerFrame:GetColorRGB()
	options.procpanel.MwColorSelect:GetNormalTexture():SetVertexColor(r, v, b, a)
	TeOptions.Mw.Color.r, TeOptions.Mw.Color.v, TeOptions.Mw.Color.b, TeOptions.Mw.Color.a = r, v, b, a
	MwSetColor()
end

local function MwColorSelect_Cancel()
	local a, r, v, b = MwOpacityPrevious, ColorPicker_GetPreviousValues()
	options.procpanel.MwColorSelect:GetNormalTexture():SetVertexColor(r, v, b, a)
	TeOptions.Mw.Color.r, TeOptions.Mw.Color.v, TeOptions.Mw.Color.b, TeOptions.Mw.Color.a = r, v, b, a
	MwSetColor()
end

local function ShockSelectOnClick(self)
	UIDropDownMenu_SetSelectedID(options.debuffpanel.ShockSelectDropDown, self:GetID())
	TeOptions.Shock.Type = self.value
	ShockSetTexture()
	if not TeOptions.Lock then TeEditMode() end
end

local function ShockSelectInitialize(self, level)
	local shockType = {
		{ name = GetSpellInfo(8050),
			value = "fls",},
		{ name = GetSpellInfo(8056),
			value = "frs",},
		{name = GetSpellInfo(8042),
			value = "es",},
	}
	local info = UIDropDownMenu_CreateInfo()
	for k,v in pairs(shockType) do
		info = UIDropDownMenu_CreateInfo()
		info.text = v.name
		info.value = v.value
		info.func = ShockSelectOnClick
		UIDropDownMenu_AddButton(info, level)
		if v.value == TeOptions.Shock.Type then
			UIDropDownMenu_SetSelectedID(self, k)
		end
	end
end

local function LsSoundOnClick(self)
	UIDropDownMenu_SetSelectedID(options.debuffpanel.LsSoundDropDown, self:GetID())
	TeOptions.Ls.Sound = self.value
	PlaySoundFile(self.value)
end

local function LsSoundInitialize(self, level)
	local soundbank = getsoundbank()
	local info = UIDropDownMenu_CreateInfo()
	for k,v in pairs(soundbank) do
		info = UIDropDownMenu_CreateInfo()
		info.text = v
		info.value = v
		info.func = LsSoundOnClick
		UIDropDownMenu_AddButton(info, level)
		if v == TeOptions.Ls.Sound then
			UIDropDownMenu_SetSelectedID(self, k)
		end
	end
end

local function TtBuffCheckOnClick(self)
	UIDropDownMenu_SetSelectedID(options.totempanel.TtBuffCheckDropDown, self:GetID())
	TeOptions.Tt.BuffCheckMode = self.value
end

local function TtBuffCheckInitialize(self, level)
	local buffcheck = {
		{ name = DISABLE,
			value = "disable",},
		{ name = BAR,
			value = "bar",},
		{name = TEXTURE,
			value = "texture",},
	}
	local info = UIDropDownMenu_CreateInfo()
	for k,v in pairs(buffcheck) do
		info = UIDropDownMenu_CreateInfo()
		info.text = v.name
		info.value = v.value
		info.func = TtBuffCheckOnClick
		UIDropDownMenu_AddButton(info, level)
		if v.value == TeOptions.Tt.BuffCheckMode then
			UIDropDownMenu_SetSelectedID(self, k)
		end
	end
end

function buildoptions()
	options_initialized = true
	
	--general settings panel
	options.genepanel.GenSetText = create_fontstring("GenSetText", options.genepanel, "GameFontNormalLarge", GENERALSETTINGS)
	options.genepanel.GenSetText:SetPoint("TOPLEFT", 16, -16)
	options.genepanel.GenSetDescText = create_fontstring("GenSetDescText", options.genepanel, "GameFontHighlightSmall", GENERALSETTINGSDESC)
	options.genepanel.GenSetDescText:SetPoint("TOPLEFT", GenSetText, "BOTTOMLEFT", 0, 0)
	
	options.genepanel.TeResetBtn = create_button("TeResetBtn", options.genepanel, RESETSETTING)
	options.genepanel.TeResetBtn:SetPoint("TOPLEFT", 12, -55)
	options.genepanel.TeResetBtn:SetScript("OnClick", resetall)
	
	options.genepanel.TeFrameResetBtn = create_button("TeFrameResetBtn", options.genepanel, RESETPOS)
	options.genepanel.TeFrameResetBtn:SetPoint("TOPLEFT", 200, -55)
	options.genepanel.TeFrameResetBtn:SetScript("OnClick", function() TeLockFrame("reset") end)

	options.genepanel.TeLockChkBtn = create_chkbutton("TeLockChkBtn", options.genepanel, LOCKFRAME)
	options.genepanel.TeLockChkBtn:SetPoint("TOPLEFT", 12, -80)
	options.genepanel.TeLockChkBtn:SetScript("OnClick", function(self)
		TeOptions.Lock = self:GetChecked()
		if self:GetChecked() then
			TeLockFrame()
		else
			TeEditMode()
		end
	end)
	
	options.genepanel.TeBlizzChkBtn = create_chkbutton("TeBlizzChkBtn", options.genepanel, BLIZZMOVE)
	options.genepanel.TeBlizzChkBtn:SetPoint("TOPLEFT", 12, -105)
	options.genepanel.TeBlizzChkBtn:SetScript("OnClick", function(self)
		if self:GetChecked() then
			TeOptions.BlizzMove = true
			TeBlizzMove()
		else
			TeOptions.BlizzMove = false
			InterfaceOptionsFrame:ClearAllPoints()
			InterfaceOptionsFrame:SetPoint("center")
			InterfaceOptionsFrame:SetMovable(false)
		end
	end)
	
	options.genepanel.TeSimExportBtn = create_button("TeSimExportBtn", options.genepanel, ENHSIMEXPORTBTNTEXT)
	options.genepanel.TeSimExportBtn:SetPoint("TOPLEFT", 105, -150)
	options.genepanel.TeSimExportBtn:SetScript("OnClick", function() StaticPopup_Show("SIM_EXPORT") end)
	
	--proc panel
	options.procpanel.MwSetText = create_fontstring("MwSetText", options.procpanel, "GameFontNormalLarge", PROCSETTINGS)
	options.procpanel.MwSetText:SetPoint("TOPLEFT", 16, -16)
	options.procpanel.MwSetDescText = create_fontstring("MwSetDescText", options.procpanel, "GameFontHighlightSmall", PROCSETTINGSDESC)
	options.procpanel.MwSetDescText:SetPoint("TOPLEFT", MwSetText, "BOTTOMLEFT", 0, 0)
	
	options.procpanel.MwEnableChkBtn = create_chkbutton("MwEnableChkBtn", options.procpanel, MAELSTROMWENABLE)
	options.procpanel.MwEnableChkBtn:SetPoint("TOPLEFT", 12, -50)
	options.procpanel.MwEnableChkBtn:SetScript("OnClick", function(self)
		TeOptions.Mw.On = self:GetChecked()
		options.panel.refresh()
	end)
	
	options.procpanel.LsFullStackEnableChkBtn = create_chkbutton("LsFullStackEnableChkBtn", options.procpanel, LSFSENABLE)
	options.procpanel.LsFullStackEnableChkBtn:SetPoint("TOPLEFT", 12, -75)
	options.procpanel.LsFullStackEnableChkBtn:SetScript("OnClick", function(self)
		TeOptions.Ls.Fsp = self:GetChecked()
	end)
	
	options.procpanel.MwAnimChkBtn = create_chkbutton("MwAnimChkBtn", options.procpanel, LOGOANIM)
	options.procpanel.MwAnimChkBtn:SetPoint("TOPLEFT", 32, -100)
	options.procpanel.MwAnimChkBtn:SetScript("OnClick", function(self)
		TeOptions.Mw.EnableAnim = self:GetChecked()
		options.panel.refresh()
	end)
	
	options.procpanel.MwSoundDropDown = create_dropdown("MwSoundDropDown", options.procpanel, SOUND)
	options.procpanel.MwSoundDropDown:SetPoint("TOPLEFT", 16, -140)
	
	options.procpanel.MwTextureDropDown = create_dropdown("MwTextureDropDown", options.procpanel, TEXTURE)
	options.procpanel.MwTextureDropDown:SetPoint("TOPLEFT", 16, -185)
	
	options.procpanel.MwColorSelect = create_colorpickerbuton("MwColorSelect", options.procpanel, COLOR)
	options.procpanel.MwColorSelect:SetPoint("TOPLEFT", 190, -190)
	options.procpanel.MwColorSelect:SetScript("OnClick", function()
		if ColorPickerFrame:IsShown() then
			ColorPickerFrame:Hide()
		else
			local info = UIDropDownMenu_CreateInfo()
			info.r, info.g, info.b, info.a = TeOptions.Mw.Color.r, TeOptions.Mw.Color.v, TeOptions.Mw.Color.b, TeOptions.Mw.Color.a
			MwOpacityPrevious = info.a
			info.swatchFunc = MwColorSelect_Swatch
			info.cancelFunc = MwColorSelect_Cancel
			info.opacityFunc = MwColorSelect_Swatch
			info.hasOpacity = info.a ~= nil
			info.opacity = info.a
			OpenColorPicker(info)
		end
	end)
	
	options.procpanel.MwScaleSlider = create_slider("MwScaleSlider", options.procpanel, "200%", "1%", 200, 1, SCALE)
	options.procpanel.MwScaleSlider:SetPoint("TOPLEFT", 37, -230)
	options.procpanel.MwScaleSlider:SetScript("OnValueChanged", function(self)
		MwScaleSliderText:SetText(self:GetValue().."%")
		TeOptions.Mw.Size = self:GetValue()/100 * 200
		MwSetSize()
	end)
	
	options.procpanel.LavaSurgeChkBtn = create_chkbutton("LavaSurgeChkBtn", options.procpanel, LAVESURGENABLE)
	options.procpanel.LavaSurgeChkBtn:SetPoint("TOPLEFT", 12, -260)
	options.procpanel.LavaSurgeChkBtn:SetScript("OnClick", function(self)
		TeOptions.Lsurge.On = self:GetChecked()
		options.panel.refresh()
	end)
	
	options.procpanel.LavaSurgeSoundDropDown = create_dropdown("LavaSurgeSound", options.procpanel, SOUND)
	options.procpanel.LavaSurgeSoundDropDown:SetPoint("TOPLEFT", 16, -300)
	UIDropDownMenu_SetWidth(options.procpanel.LavaSurgeSoundDropDown, 200)
	
	options.procpanel.LavaSurgeScaleSlider = create_slider("LavaSurgeScaleSlider", options.procpanel, "200%", "1%", 200, 1, SCALE)
	options.procpanel.LavaSurgeScaleSlider:SetPoint("TOPLEFT", 37, -345)
	options.procpanel.LavaSurgeScaleSlider:SetScript("OnValueChanged", function(self)
		LavaSurgeScaleSliderText:SetText(self:GetValue().."%")
		TeOptions.Lsurge.Scale = self:GetValue()
		LavaSurgeSetSize()
	end)
	
	--debuff panel
	options.debuffpanel.DebuffSetText = create_fontstring("DebuffSetText", options.debuffpanel, "GameFontNormalLarge", DEBUFFPANELSETTINGS)
	options.debuffpanel.DebuffSetText:SetPoint("TOPLEFT", 16, -16)
	options.debuffpanel.DebuffSetDescText = create_fontstring("DebuffSetDescText", options.debuffpanel, "GameFontHighlightSmall", DEBUFFPANELSETTINGSDESC)
	options.debuffpanel.DebuffSetDescText:SetPoint("TOPLEFT", DebuffSetText, "BOTTOMLEFT", 0, 0)
	
	options.debuffpanel.SsEnableChkBtn = create_chkbutton("SsEnableChkBtn", options.debuffpanel, SSENABLE)
	options.debuffpanel.SsEnableChkBtn:SetPoint("TOPLEFT", 12, -50)
	options.debuffpanel.SsEnableChkBtn:SetScript("OnClick", function(self)
		TeOptions.Ss.On = self:GetChecked()
		options.panel.refresh()
	end)
	
	options.debuffpanel.TwEnableChkBtn = create_chkbutton("TwEnableChkBtn", options.debuffpanel, TWENABLE)
	options.debuffpanel.TwEnableChkBtn:SetPoint("TOPLEFT", 12, -75)
	options.debuffpanel.TwEnableChkBtn:SetScript("OnClick", function(self)
		TeOptions.Tw.On = self:GetChecked()
		options.panel.refresh()
	end)
	
	options.debuffpanel.LbEnableChkBtn = create_chkbutton("LbEnableChkBtn", options.debuffpanel, LBENABLE)
	options.debuffpanel.LbEnableChkBtn:SetPoint("TOPLEFT", 12, -100)
	options.debuffpanel.LbEnableChkBtn:SetScript("OnClick", function(self)
		TeOptions.Lb.On = self:GetChecked()
		options.panel.refresh()
	end)
	
	options.debuffpanel.ShockEnableChkBtn = create_chkbutton("ShockEnableChkBtn", options.debuffpanel, SHOCKENABLE)
	options.debuffpanel.ShockEnableChkBtn:SetPoint("TOPLEFT", 12, -125)
	options.debuffpanel.ShockEnableChkBtn:SetScript("OnClick", function(self)
		TeOptions.Shock.On = self:GetChecked()
		options.panel.refresh()
	end)
	
	options.debuffpanel.ShockSelectDropDown = create_dropdown("ShockSelectDropDown", options.debuffpanel)
	options.debuffpanel.ShockSelectDropDown:SetPoint("TOPRIGHT", -130, -125)
	
	options.debuffpanel.LsEnableChkBtn = create_chkbutton("LsEnableChkBtn", options.debuffpanel, LSENABLE)
	options.debuffpanel.LsEnableChkBtn:SetPoint("TOPLEFT", 12, -150)
	options.debuffpanel.LsEnableChkBtn:SetScript("OnClick", function(self)
		TeOptions.Ls.On = self:GetChecked()
		options.panel.refresh()
	end)
	
	options.debuffpanel.LsOocChkBtn = create_chkbutton("LsOocChkBtn", options.debuffpanel, ALLOWOOC)
	options.debuffpanel.LsOocChkBtn:SetPoint("TOPLEFT", 32, -175)
	options.debuffpanel.LsOocChkBtn:SetScript("OnClick", function(self)
		TeOptions.Ls.Ooc = self:GetChecked()
		if TeOptions.Lock then
			TeDebuffFrame.ls:Hide()
		end
	end)
	
	options.debuffpanel.LsSoundDropDown = create_dropdown("LsSoundDropDown", options.debuffpanel, SOUND)
	options.debuffpanel.LsSoundDropDown:SetPoint("TOPLEFT", 20, -215)
	UIDropDownMenu_SetWidth(options.debuffpanel.LsSoundDropDown, 200)
	
	options.debuffpanel.EshieEnableChkBtn = create_chkbutton("EshieEnableChkBtn", options.debuffpanel, ESHIENABLE)
	options.debuffpanel.EshieEnableChkBtn:SetPoint("TOPLEFT", 12, -245)
	options.debuffpanel.EshieEnableChkBtn:SetScript("OnClick", function(self)
		TeOptions.Eshi.On = self:GetChecked()
		options.panel.refresh()
	end)
	
	options.debuffpanel.PurgeEnableChkBtn = create_chkbutton("PurgeEnableChkBtn", options.debuffpanel, PURGEENABLE)
	options.debuffpanel.PurgeEnableChkBtn:SetPoint("TOPLEFT", 12, -270)
	options.debuffpanel.PurgeEnableChkBtn:SetScript("OnClick", function(self)
		TeOptions.Purge.On = self:GetChecked()
		options.panel.refresh()
	end)
	
	options.debuffpanel.UeEnableChkBtn = create_chkbutton("UeEnableChkBtn", options.debuffpanel, UEENABLE)
	options.debuffpanel.UeEnableChkBtn:SetPoint("TOPLEFT", 12, -295)
	options.debuffpanel.UeEnableChkBtn:SetScript("OnClick", function(self)
		TeOptions.Ue.On = self:GetChecked()
	end)
	
	options.debuffpanel.DebuffScaleSlider = create_slider("DebuffScaleSlider", options.debuffpanel, "200%", "1%", 200, 1, SCALE)
	options.debuffpanel.DebuffScaleSlider:SetPoint("TOPLEFT", 18, -340)
	options.debuffpanel.DebuffScaleSlider:SetScript("OnValueChanged", function(self)
		DebuffScaleSliderText:SetText(self:GetValue().."%")
		TeOptions.DebuffSize = self:GetValue()/100 * 64
		OrderDebuffFrame()
	end)
	
	options.debuffpanel.DebuffFlashDelaySlider = create_slider("DebuffFlashDelaySlider", options.debuffpanel, "10s", DISABLE, 10, 0, FLASHDELAY)
	options.debuffpanel.DebuffFlashDelaySlider:SetPoint("TOPLEFT", 18, -380)
	options.debuffpanel.DebuffFlashDelaySlider:SetScript("OnValueChanged", function(self)
		DebuffFlashDelaySliderText:SetText(self:GetValue().."s")
		TeOptions.DebuffFlashDelay = self:GetValue()
	end)
	
	--weapon panel
	options.weaponpanel.WeaponSetText = create_fontstring("WeaponSetText", options.weaponpanel, "GameFontNormalLarge", WEAPONPANELSETTINGS)
	options.weaponpanel.WeaponSetText:SetPoint("TOPLEFT", 16, -16)
	options.weaponpanel.WeaponSetDescText = create_fontstring("WeaponSetDescText", options.weaponpanel, "GameFontHighlightSmall", WEAPONPANELSETTINGSDESC)
	options.weaponpanel.WeaponSetDescText:SetPoint("TOPLEFT", WeaponSetText, "BOTTOMLEFT", 0, 0)
	
	options.weaponpanel.WbEnableChkBtn = create_chkbutton("WbEnableChkBtn", options.weaponpanel, WBENABLE)
	options.weaponpanel.WbEnableChkBtn:SetPoint("TOPLEFT", 12, -50)
	options.weaponpanel.WbEnableChkBtn:SetScript("OnClick", function(self)
		TeOptions.Weapon.On = self:GetChecked()
		options.panel.refresh()
	end)
	
	options.weaponpanel.WbOocTracking = create_chkbutton("WbOocTracking", options.weaponpanel, ALLOWOOC)
	options.weaponpanel.WbOocTracking:SetPoint("TOPLEFT", 32, -75)
	options.weaponpanel.WbOocTracking:SetScript("OnClick", function(self)
		TeOptions.Weapon.Ooc = self:GetChecked()
		if TeOptions.Lock then
			TeWeaponFrame.mh:Hide()
			TeWeaponFrame.oh:Hide()
		end
	end)
	
	options.weaponpanel.WrRadiusSlider = create_slider("WrRadiusSlider", options.weaponpanel, "400", "1", 400, 1, RADIUS)
	options.weaponpanel.WrRadiusSlider:SetPoint("TOPLEFT", 18, -115)
	options.weaponpanel.WrRadiusSlider:SetScript("OnValueChanged", function(self)
		WrRadiusSliderText:SetText(self:GetValue())
		TeOptions.Weapon.Radius = self:GetValue()
		WbSetRadius()
	end)
	
	options.weaponpanel.WpScaleSlider = create_slider("WpScaleSlider", options.weaponpanel, "200%", "1%", 200, 1, SCALE)
	options.weaponpanel.WpScaleSlider:SetPoint("TOPLEFT", 18, -155)
	options.weaponpanel.WpScaleSlider:SetScript("OnValueChanged", function(self)
		WpScaleSliderText:SetText(self:GetValue().."%")
		TeOptions.Weapon.Size = self:GetValue()/100*40
		WpSetScale()
	end)
	
	options.weaponpanel.WbFlashDelaySlider = create_slider("WbFlashDelaySlider", options.weaponpanel, "120s", DISABLE, 120, 0, FLASHDELAY)
	options.weaponpanel.WbFlashDelaySlider:SetPoint("TOPLEFT", 18, -195)
	options.weaponpanel.WbFlashDelaySlider:SetScript("OnValueChanged", function(self)
		WbFlashDelaySliderText:SetText(self:GetValue().."s")
		TeOptions.Weapon.FlashDelay = self:GetValue()
	end)
	
	--totem panel
	options.totempanel.TotemSetText = create_fontstring("TotemSetText", options.totempanel, "GameFontNormalLarge", TOTEMPANELSETTINGS)
	options.totempanel.TotemSetText:SetPoint("TOPLEFT", 16, -16)
	options.totempanel.TotemSetDescText = create_fontstring("TotemSetDescText", options.totempanel, "GameFontHighlightSmall", TOTEMPANELSETTINGSDESC)
	options.totempanel.TotemSetDescText:SetPoint("TOPLEFT", TotemSetText, "BOTTOMLEFT", 0, 0)
	
	options.totempanel.TotemEnableChkBtn = create_chkbutton("TotemEnableChkBtn", options.totempanel, TOTEMENABLE)
	options.totempanel.TotemEnableChkBtn:SetPoint("TOPLEFT", 12, -50)
	options.totempanel.TotemEnableChkBtn:SetScript("OnClick", function(self)
		TeOptions.Tt.On = self:GetChecked()
		options.panel.refresh()
	end)
	
	options.totempanel.TtBuffCheckDropDown = create_dropdown("TtBuffCheckDropDown", options.totempanel, TOTEMBUFFCHECK)
	options.totempanel.TtBuffCheckDropDown:SetPoint("TOPLEFT", 0, -90)
	
	options.totempanel.TtRadiusSlider = create_slider("TtRadiusSlider", options.totempanel, "200", "15", 200, 15, RADIUS)
	options.totempanel.TtRadiusSlider:SetPoint("TOPLEFT", 18, -140)
	options.totempanel.TtRadiusSlider:SetScript("OnValueChanged", function(self)
		TtRadiusSliderText:SetText(self:GetValue())
		TeOptions.Tt.Radius = self:GetValue()
		TtSetRadius()
	end)
	
	options.totempanel.TtScaleSlider = create_slider("TtScaleSlider", options.totempanel, "200%", "1%", 200, 1, SCALE)
	options.totempanel.TtScaleSlider:SetPoint("TOPLEFT", 18, -180)
	options.totempanel.TtScaleSlider:SetScript("OnValueChanged", function(self)
		TtScaleSliderText:SetText(self:GetValue().."%")
		TeOptions.Tt.Size = self:GetValue()/100*64
		TtSetScale()
	end)
	
	options.totempanel.TtFlashDelaySlider = create_slider("TtFlashDelaySlider", options.totempanel, "60s", DISABLE, 60, 0, FLASHDELAY)
	options.totempanel.TtFlashDelaySlider:SetPoint("TOPLEFT", 18, -220)
	options.totempanel.TtFlashDelaySlider:SetScript("OnValueChanged", function(self)
		TtFlashDelaySliderText:SetText(self:GetValue().."s")
		TeOptions.Tt.FlashDelay = self:GetValue()
	end)
end

function TeEditMode()
	TeLockFrame()
	if TeOptions.Mw.On and TeOptions.Mw.EnableAnim then
		TeMwFrame.ag:Stop()
		for i=1, 5 do
			TeMwFrame.texture[i]:Show()
		end
		TeMwFrame:EnableMouse(true)
	end
	if TeOptions.Ss.On and SpellUsable(17364) then
		TeDebuffFrame.ss:Show()
		TeDebuffFrame.ss.ag:Stop()
	end
	if TeOptions.Tw.On and Twlearn() then
		TeDebuffFrame.tw:Show()
		TeDebuffFrame.tw.ag:Stop()
	end
	if TeOptions.Lb.On and SpellUsable(51505) and CurrentSpec == "elem" then
		TeDebuffFrame.lb:Show()
		TeDebuffFrame.lb.ag:Stop()
	end
	if TeOptions.Lsurge.On and SpellUsable(51505) and CurrentSpec == "elem" then
		TeflameFrame:Show()
		TeflameFrame.ag:Stop()
		TeflameFrame:EnableMouse(true)
	end
	if TeOptions.Shock.On and SpellUsable(8042) and CurrentSpec ~= "resto" then
		TeDebuffFrame.shock:Show()
		TeDebuffFrame.shock.ag:Stop()
	end
	if TeOptions.Ls.On and SpellUsable(324) then
		TeDebuffFrame.ls:Show()
		TeDebuffFrame.ls.ag:Stop()
	end
	if TeOptions.Eshi.On and SpellUsable(974) then
		TeDebuffFrame.eshi:Show()
		TeDebuffFrame.eshi.ag:Stop()
	end
	if TeOptions.Purge.On and SpellUsable(370) then
		TeDebuffFrame.purge:Show()
	end
	TeDebuffFrame:EnableMouse(true)
	if TeOptions.Tt.On then
		for i=1,4 do
			TeTtFrame.totem[i]:Show()
			TeTtFrame.totem[i].ag:Stop()
		end
	end
	if TeOptions.Weapon.On then
		TeWeaponFrame.mh:Show()
		TeWeaponFrame.mh.ag:Stop()
		TeWeaponFrame.oh:Show()
		TeWeaponFrame.oh.ag:Stop()
	end
	TeOptions.Lock = false
end

options = {}
options.panel = CreateFrame("Frame")
options.panel.name = "TribalEnhancement"

options.genepanel = CreateFrame("Frame")
options.genepanel.name = GENERALSETTINGS
options.genepanel.parent = options.panel.name

options.procpanel = CreateFrame("Frame")
options.procpanel.name = PROCSETTINGS
options.procpanel.parent = options.panel.name

options.debuffpanel = CreateFrame("Frame")
options.debuffpanel.name = DEBUFFPANELSETTINGS
options.debuffpanel.parent = options.panel.name

options.weaponpanel = CreateFrame("Frame")
options.weaponpanel.name = WEAPONPANELSETTINGS
options.weaponpanel.parent = options.panel.name

options.totempanel = CreateFrame("Frame")
options.totempanel.name = TOTEMPANELSETTINGS
options.totempanel.parent = options.panel.name

for k, v in pairs(options) do
	v:SetScript('OnShow', function(self)
		if v.name == "TribalEnhancement" then
			InterfaceOptionsFrame_OpenToCategory(options.genepanel)
			self:Hide()
		end
		if not options_initialized then
			buildoptions()
			options.panel.refresh()
		end
	end)
end

InterfaceOptions_AddCategory(options.panel)
InterfaceOptions_AddCategory(options.genepanel)
InterfaceOptions_AddCategory(options.procpanel)
InterfaceOptions_AddCategory(options.debuffpanel)
InterfaceOptions_AddCategory(options.weaponpanel)
InterfaceOptions_AddCategory(options.totempanel)

function options.panel.refresh()
	if not TeOptions.Lock then TeEditMode() end
	OrderDebuffFrame()
	
	options.genepanel.TeLockChkBtn:SetChecked(TeOptions.Lock)
	options.genepanel.TeBlizzChkBtn:SetChecked(TeOptions.BlizzMove)
	
	options.procpanel.MwEnableChkBtn:SetChecked(TeOptions.Mw.On)
	options.procpanel.LsFullStackEnableChkBtn:SetChecked(TeOptions.Ls.Fsp)
	options.procpanel.MwAnimChkBtn:SetChecked(TeOptions.Mw.EnableAnim)
	UIDropDownMenu_Initialize(options.procpanel.MwSoundDropDown, MwSoundInitialize)
	UIDropDownMenu_Initialize(options.procpanel.MwTextureDropDown, MwTextureInitialize)
	options.procpanel.MwColorSelect:GetNormalTexture():SetVertexColor(TeOptions.Mw.Color.r, TeOptions.Mw.Color.v, TeOptions.Mw.Color.b, TeOptions.Mw.Color.a)
	options.procpanel.MwScaleSlider:SetValue(TeOptions.Mw.Size/200 * 100)
	MwScaleSliderText:SetText(math.ceil(TeOptions.Mw.Size/200 * 100).."%")
	options.procpanel.LavaSurgeChkBtn:SetChecked(TeOptions.Lsurge.On)
	UIDropDownMenu_Initialize(options.procpanel.LavaSurgeSoundDropDown, LavaSurgeSoundInitialize)
	options.procpanel.LavaSurgeScaleSlider:SetValue(TeOptions.Lsurge.Scale)
	LavaSurgeScaleSliderText:SetText(TeOptions.Lsurge.Scale.."%")
	
	options.debuffpanel.SsEnableChkBtn:SetChecked(TeOptions.Ss.On)
	options.debuffpanel.TwEnableChkBtn:SetChecked(TeOptions.Tw.On)
	options.debuffpanel.LbEnableChkBtn:SetChecked(TeOptions.Lb.On)
	options.debuffpanel.ShockEnableChkBtn:SetChecked(TeOptions.Shock.On)
	UIDropDownMenu_Initialize(options.debuffpanel.ShockSelectDropDown, ShockSelectInitialize)
	options.debuffpanel.LsEnableChkBtn:SetChecked(TeOptions.Ls.On)
	options.debuffpanel.LsOocChkBtn:SetChecked(TeOptions.Ls.Ooc)
	UIDropDownMenu_Initialize(options.debuffpanel.LsSoundDropDown, LsSoundInitialize)
	options.debuffpanel.EshieEnableChkBtn:SetChecked(TeOptions.Eshi.On)
	options.debuffpanel.PurgeEnableChkBtn:SetChecked(TeOptions.Purge.On)
	options.debuffpanel.UeEnableChkBtn:SetChecked(TeOptions.Ue.On)
	options.debuffpanel.DebuffScaleSlider:SetValue(TeOptions.DebuffSize/64 * 100)
	DebuffScaleSliderText:SetText(math.ceil(TeOptions.DebuffSize/64 * 100).."%")
	options.debuffpanel.DebuffFlashDelaySlider:SetValue(TeOptions.DebuffFlashDelay)
	DebuffFlashDelaySliderText:SetText(TeOptions.DebuffFlashDelay.."s")
	
	options.weaponpanel.WbEnableChkBtn:SetChecked(TeOptions.Weapon.On)
	options.weaponpanel.WbOocTracking:SetChecked(TeOptions.Weapon.Ooc)
	options.weaponpanel.WrRadiusSlider:SetValue(TeOptions.Weapon.Radius)
	WrRadiusSliderText:SetText(math.ceil(TeOptions.Weapon.Radius))
	options.weaponpanel.WpScaleSlider:SetValue(TeOptions.Weapon.Size/40*100)
	WpScaleSliderText:SetText(math.ceil(TeOptions.Weapon.Size/40*100).."%")
	options.weaponpanel.WbFlashDelaySlider:SetValue(TeOptions.Weapon.FlashDelay)
	WbFlashDelaySliderText:SetText(TeOptions.Weapon.FlashDelay.."s")
	
	options.totempanel.TotemEnableChkBtn:SetChecked(TeOptions.Tt.On)
	UIDropDownMenu_Initialize(options.totempanel.TtBuffCheckDropDown, TtBuffCheckInitialize)
	options.totempanel.TtRadiusSlider:SetValue(TeOptions.Tt.Radius)
	TtRadiusSliderText:SetText(math.ceil(TeOptions.Tt.Radius))
	options.totempanel.TtScaleSlider:SetValue(TeOptions.Tt.Size/64*100)
	TtScaleSliderText:SetText(math.ceil(TeOptions.Tt.Size/64*100).."%")
	options.totempanel.TtFlashDelaySlider:SetValue(TeOptions.Tt.FlashDelay)
	TtFlashDelaySliderText:SetText(TeOptions.Tt.FlashDelay.."s")
end

function options.panel.okay() TeLockFrame() TeOptions.Lock = true end
function options.panel.cancel() TeLockFrame() TeOptions.Lock = true end
